==> ejc-bid-impl-3.0.0-20211204.061906-92-sources.jar: com/ejianc/business/bid/bean/RecordEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

/**
 * 投标记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_record")
public class RecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value="bid_stage_name")
    private String bidStageName; // 阶段名称
    @TableField(value="bill_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billDate; // 创建日期
    @TableField(value="bid_stage")
    private Integer bidStage; // 阶段标志
    @TableField(value="bill_id")
    private Long billId; // 单据id


    public String getEngineeringCode() {
        return engineeringCode;
    }

    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }

    public String getBidStageName() {
        return bidStageName;
    }

    public void setBidStageName(String bidStageName) {
        this.bidStageName = bidStageName;
    }

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }

    public Integer getBidStage() {
        return bidStage;
    }

    public void setBidStage(Integer bidStage) {
        this.bidStage = bidStage;
    }

    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
}

==> ejc-bid-impl-3.0.0-20231110.090842-391-sources.jar: com/ejianc/business/bid/bean/RecordEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

/**
 * 投标记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_record")
public class RecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value="bid_stage_name")
    private String bidStageName; // 阶段名称
    @TableField(value="bill_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date billDate; // 创建日期
    @TableField(value="bid_stage")
    private Integer bidStage; // 阶段标志
    @TableField(value="bill_id")
    private Long billId; // 单据id


    public String getEngineeringCode() {
        return engineeringCode;
    }

    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }

    public String getBidStageName() {
        return bidStageName;
    }

    public void setBidStageName(String bidStageName) {
        this.bidStageName = bidStageName;
    }

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }

    public Integer getBidStage() {
        return bidStage;
    }

    public void setBidStage(Integer bidStage) {
        this.bidStage = bidStage;
    }

    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
}
